<?php
// mysql_php_edition.php
// Released on July 12, 2011
// Last update on July 23, 2011
// Author: Juan Valencia Escalante <contact@jveweb.net>
// For new versions visit:
// http://www.jveweb.net/en/archives/2011/07/prepared-mysql-statements-in-php-object-oriented-examples.html

// This script is called from mysql_php_show.php when the edit link is clicked
// Of course it may also be called by adding a ?id=x after the .php
//   where x is the ID of the record that we want to edit
// It may receive the ID in a post request when we edit the record
// If no ID is found, we read the first ID found in the database

header('Content-type: text/html; charset=utf8');

include_once('settings.php');

$message = "";

// Connect to the edatabase
$mysqli = new mysqli($mysql_host, $mysql_username, $mysql_password, $mysql_database);
if (mysqli_connect_errno()) {
    die("Can not connect to the database: " . mysqli_connect_error());
}

// Change character set to utf8
if (!$mysqli->set_charset("utf8")) {
    die("Error loading character set utf8: %s\n" . $mysqli->error);
}

// Check if we received an ID
if (isset($_GET["id"]) || isset($_POST["id"])) {

    // If we received an ID, then store it in $tmp_id;
    // They are handled in this order so the post request takes
    //   precedence over the get request
    if (isset($_GET["id"])) {
        $tmp_id = $_GET["id"];
    }
    if (isset($_POST["id"])) {
        $tmp_id = $_POST["id"];
    }

    // If we received 1 in $_POST["edit"], update the record
    if ($_POST["edit"] == "1") {

        // Some basic XSS prevention
        // Strip the html tags to prevent XSS attacks when you display the
        //   information inside other elements
        // In adition, if you are going to put text into the value attribute
        //   of an input element, and you use double quotes as delimiters, then
        //   also strip the double quotes of this fields, the same goes for
        //   single quotes
        $tmp_name = strip_tags($_POST["name"]);
        $tmp_address = strip_tags($_POST["address"]);
        $tmp_email = strip_tags($_POST["email"]);
        $tmp_name = str_replace('"', '', $tmp_name);
        $tmp_address = str_replace('"', '', $tmp_address);
        $tmp_email = str_replace('"', '', $tmp_email);

        // Create the prepared MySQL statement, bind the variables and execute it
        if ($stmt = $mysqli->prepare("update `jveweb_net_test_table` set
            `field_name`=?,`field_address`=?,`field_email`=?,`field_modified`=NOW()
            where `field_id` = ?") ) {
            $stmt->bind_param('sssd', $tmp_name, $tmp_address, $tmp_email, $tmp_id);
            $stmt->execute();

            if ($stmt->affected_rows > 0) {
                $message = "<p><b>The record with the ID $tmp_id was successfully updated.</b></p>\n";
            }

            // Close the prepared MySQL statement
            $stmt->close();
        }
    }

    // Read the database entry with the given ID
    // We reset the temporal variables, so when we display the information
    //   in the form after an edition, what we see is the stored data
    $tmp_name = "";
    $tmp_address = "";
    $tmp_email = "";

    // Create the prepared MySQL statement, bind the variables and execute it
    if ($stmt = $mysqli->prepare("select `field_name`,`field_address`,`field_email` from `jveweb_net_test_table` where `field_id` = ?")) {
        $stmt->bind_param('d', $tmp_id);
        $stmt->execute();

        // We bind the results and fetch the data
        $stmt->bind_result($tmp_name, $tmp_address, $tmp_email);
        $stmt->fetch();

        // Close the prepared MySQL statement
        $stmt->close();
    }

} else {
    // If we didn't receive an ID, obtain the first record in the database
    $query = "select * from `jveweb_net_test_table` limit 1";
    $result = $mysqli->query($query);
    if ($result) {
        if ($row = $result->fetch_assoc()) {

            $tmp_id = $row["field_id"];
            $tmp_name = $row["field_name"];
            $tmp_address = $row["field_address"];
            $tmp_email = $row["field_email"];
        }
    }
}

// Close  the MySQL connection
$mysqli->close();

?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    <meta name="keywords" content="" />
    <meta name="description" content="" />
    <meta name="author" content="Juan Valencia Escalante" />
    <title>MySQL/PHP Edition example - Juan Valencia's website - jveweb.net</title>
    <style type="text/css">
        form {
            width:300px;
        }
        label {
            float:left;
            width:50px;
            text-align:right;
            padding-right:5px;
            clear:left;
        }
        input {
            float:left;
            width:200px;
        }
        .button {
            width:100px;
        }
    </style>
</head>
<body>
    <div id="content">
        <form action="mysql_php_edition.php" method="post" accept-charset="utf-8">
            <fieldset>
                <legend>Simple form for edit a record</legend>
                <label for"name">Name:</label> <input type="text" name="name" id="name"  value="<?=$tmp_name;?>" />
                <label for="address">Address:</label> <input type="text" name="address" id="address" value="<?=$tmp_address;?>" />
                <label for="email">E-mail:</label> <input type="text" name="email" id="email" value="<?=$tmp_email;?>" />
                <input type="submit" class="button" />
                <input type="hidden" name="id" value="<?=$tmp_id;?>" />
                <input type="hidden" name="edit" value="1" />
            </fieldset>
        </form>
        <?=$message;?>
        <p>
            <a href="mysql_php_show.php">Show the records</a><br />
            <a href="mysql_php_insertion.php">Insert a new record</a><br />
            <a href="mysql_php_deletion.php">Delete fields</a><br />
            <a href="mysql_php_create_table.php?reset=1">Reset the table</a>
        </p>
    </div>
</body>
</html>
