<?php
// mysql_php_show.php
// Released on July 12, 2011
// Last update on July 23, 2011
// Author: Juan Valencia Escalante <contact@jveweb.net>
// For new versions visit:
// http://www.jveweb.net/en/archives/2011/07/prepared-mysql-statements-in-php-object-oriented-examples.html

// In this example I show the records in a table

// If the variables $_POST["start"] and $_POST["end"] contain data, then
//   a prepared MySQL statement is created, and the result is processed by using
//   the functions mysqli_stmt_bind_result() and mysqli_stmt_fetch().

// If not, then a simple query is used, and the result is processed by using
//   the funcion mysqli_fetch_assoc().

header('Content-type: text/html; charset=utf8');

include_once('settings.php');

$message = "";

// Connect to the database
$mysqli = new mysqli($mysql_host, $mysql_username, $mysql_password, $mysql_database);
if (mysqli_connect_errno()) {
    die("Can not connect to the database: " . mysqli_connect_error());
}

// Change character set to utf8
if (!$mysqli->set_charset("utf8")) {
    die("Error loading character set utf8: %s\n" . $mysqli->error);
}

// Create the table and its column headers
$table = <<<THETABLE
<table cellspacing="0" summary="The results of a simple select query">
    <caption>List of records in the database</caption>
    <thead>
        <tr>
            <th scope="col">field_id</th>
            <th scope="col">field_name</th>
            <th scope="col">field_address</th>
            <th scope="col">field_email</th>
            <th scope="col">field_created</th>
            <th scope="col">field_modified</th>
            <th scope="col">actions</th>
        </tr>
    </thead>
    <tbody>
THETABLE;

$displayed_records = 0;

// This checks if we had input from the user, create a prepared
//   MySQL statement if true, or perform a simple query if false
if ($_POST["start"] != "" && $_POST["end"] != "") {

    // THE PREPARED MySQL QUERY
    // Since we received information from the user, we create a prepared
    //   statment. This prepared statement give us information back, therefore
    //   we need to bind the result to variables to be able to use it

    // Create the prepared MySQL statement, bind the variables and execute it
    if ($stmt = $mysqli->prepare("select * from `jveweb_net_test_table` where `field_id` between ? and ?")) {
        $stmt->bind_param('dd', $_POST["start"], $_POST["end"]);
        $stmt->execute();

        // We bind the results and fetch the data
        $stmt->bind_result($tmp_id, $tmp_name, $tmp_address, $tmp_email, $tmp_created, $tmp_modified);
        while ($stmt->fetch()) {

            $table .= <<<THETABLE
        <tr>
            <td>$tmp_id</th>
            <td>$tmp_name</td>
            <td>$tmp_address</td>
            <td>$tmp_email</td>
            <td>$tmp_created</td>
            <td>$tmp_modified</td>
            <td><a href="mysql_php_edition.php?id=$tmp_id">Edit</a></td>
        </tr>
THETABLE;

            $displayed_records ++;
        }

        $message = '<br /><a href="mysql_php_show.php">Show all records</a>';

        // Close the prepared MySQL statement
        $stmt->close();
    }

// If we didn't receive input from the user
} else {

    // THE SIMPLE MySQL QUERY
    // If no query was made, display the entire table, this does not require a
    //   prepared statement since we are not using data provided by the user,
    //   a simple MySQL query is enough
    $query = "select * from `jveweb_net_test_table`";
    if ($result = $mysqli->query($query)) {
        while ($row = $result->fetch_assoc()) {

            $table .= <<<THETABLE
        <tr>
            <td>{$row["field_id"]}</th>
            <td>{$row["field_name"]}</td>
            <td>{$row["field_address"]}</td>
            <td>{$row["field_email"]}</td>
            <td>{$row["field_created"]}</td>
            <td>{$row["field_modified"]}</td>
            <td><a href="mysql_php_edition.php?id={$row["field_id"]}">Edit</a></td>
        </tr>
THETABLE;

        $displayed_records++;
        }    
    }
}

// If nothing was found in the table, create a row with an error message
if ($displayed_records == 0) {
    $table .= <<<THETABLE
        <tr>
            <td colspan="7"><b>The table is empty</b></td>
        </tr>
THETABLE;
}

// Close the html table
$table .= "    </tbody>\n</table>";

// Close  the MySQL connection
$mysqli->close();

?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml"> 
<head> 
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
    <meta name="keywords" content="" /> 
    <meta name="description" content="" /> 
    <meta name="author" content="Juan Valencia Escalante" /> 
    <title>MySQL/PHP Record listing example - Juan Valencia's website - jveweb.net</title> 
    <style type="text/css">
        table {
            background:#FFF;
            border:1px solid #CCC;
            margin:5px 0 10px;
        }
        table tbody td {
            border-top:1px solid #CCC;
            padding:2px 10px;
        }
        table thead th {
            padding:1px 10px;
            background:#EDEFF0;
            text-align:left;
        }
    </style>
</head> 
<body> 
    <div id="content"> 
        <form method="post" action="mysql_php_show.php">
            <fieldset>
                <legend>Simple form</legend>
                Show fields from <input type="text" name="start" /> to
                <input type="text" name="end" /><br />
                <input type="submit" />
                <?=$message;?>
            </fieldset>
        </form>
    <?=$table;?>
        <p>
            <a href="mysql_php_insertion.php">Insert a new record</a><br />
            <a href="mysql_php_deletion.php">Delete records</a><br />
            <a href="mysql_php_create_table.php?reset=1">Reset the table</a>
        </p>
    </div> 
</body> 
</html>
